---
title: <span class="badge object-type-scalar"></span> ReadsPerMinute
---
# <span class="badge object-type-scalar"></span> ReadsPerMinute

Throughput: reads/min (rpm)

## Definition

```python
# Throughput: reads/min (rpm)
ReadsPerMinute: typing.Literal["rpm"] = "rpm"
```
